==> haskell-connection-0.2.5-16-armv7h.pkg.tar.xz: usr/share/haskell/haskell-connection/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.5
id: connection-0.2.5-8679766890f442068d557b54b4535c5d
key: conne_2HpkLSytjYZIvMKKT5MIkR
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/connection-0.2.5
hs-libraries: HSconnection-0.2.5-2HpkLSytjYZIvMKKT5MIkR
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    socks-0.5.4-8c65994a52c136dee4fd43556a5ac65b
    tls-1.3.4-c1ffd726a31a364e53d7dbf7360c4f21
    x509-1.6.3-9c5cbae50b7250847fc648c7f7d122e6
    x509-store-1.6.1-741461c55f7edc5697c99a37f0436ee6
    x509-system-1.6.3-6ba9c22edd2365d0a08eb6f448807838
    x509-validation-1.6.3-47849fe369535aae4a3b7e2d99568d36
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.2.5-18-armv7h.pkg.tar.xz: usr/share/haskell/haskell-connection/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.5
id: connection-0.2.5-b1d9e33e03618093afb3c4e9d40c147e
key: conne_8NDWikwRg6A9LPcaOH8C9E
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/connection-0.2.5
hs-libraries: HSconnection-0.2.5-8NDWikwRg6A9LPcaOH8C9E
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    socks-0.5.4-8c65994a52c136dee4fd43556a5ac65b
    tls-1.3.5-cc53341e73a1ad5e4154c36129b6c569
    x509-1.6.3-ea92228b2bfea35f7dd001d2924d4ebd
    x509-store-1.6.1-43851738bccd019b67ff937f268f43a7
    x509-system-1.6.3-c8b329776e9eeee116761552f3bd6b7a
    x509-validation-1.6.3-2eb8745653ed8864def666b7c1efed9d
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
